@@ -17,6 +17,18 @@ from .services import DB_INSTANCES, DB_CREDENTIALS
 from .textfile import TextFile
 
 
+class StreamArray(list):
+    def __init__(self, gen, *args):
+        self.gen = gen
+        self.args = args
+
+    def __iter__(self):
+        return self.gen(*self.args)
+
+    def __len__(self):
+        return 1
+
+
 def get_selects(sql):
     sqlSelect = sql[sql.find("select") + 6:sql.find("from")]
     i = 0
@@ -212,7 +224,7 @@ class Database(object):
                 row = self.generate_one(sql)
                 yield row
 
-        return _gen(sql, limit)
+        return StreamArray(_gen, sql, limit)
 
     def get_many(self, sql, n, limit=None):
         """
@@ -231,7 +243,7 @@ class Database(object):
                 row = self.generate_one(sql)
                 yield row
 
-        return _gen(sql, limit)
+        return StreamArray(_gen, sql, limit)
 
     def get_limit_clause(self, sql, rows):
         """
